==> haskell-hasql-notifications-0.2.0.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-notifications.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-notifications
version:              0.2.0.0
visibility:           public
id:                   hasql-notifications-0.2.0.0-BycXYyiaKZD8iFmwC7hjVf
key:                  hasql-notifications-0.2.0.0-BycXYyiaKZD8iFmwC7hjVf
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  1bdbdd7582a36252ccd4af055343d12d
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.0.1/site-local/hasql-notifications-0.2.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hasql-notifications-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/hasql-notifications-0.2.0.0

hs-libraries:         HShasql-notifications-0.2.0.0-BycXYyiaKZD8iFmwC7hjVf
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    contravariant-1.5.5-1Tz7FaRP9yoKqkcBKkQ76A
    hasql-1.4.5.1-8bPl1tFwZkv69IRDtY5DI2
    hasql-pool-0.5.2-J6W7ZSstEY22mPgcPYYaIw
    postgresql-libpq-0.9.4.3-4UpE2VczKgl8p7NC0fd3Q8 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-notifications-0.2.0.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-notifications.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-notifications
version:              0.2.0.0
visibility:           public
id:                   hasql-notifications-0.2.0.0-AfwJqc4lj2S3zPmnbdSElh
key:                  hasql-notifications-0.2.0.0-AfwJqc4lj2S3zPmnbdSElh
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  c0aa914db49a6021c65dafd9bcc00225
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.0.1/site-local/hasql-notifications-0.2.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hasql-notifications-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/hasql-notifications-0.2.0.0

hs-libraries:         HShasql-notifications-0.2.0.0-AfwJqc4lj2S3zPmnbdSElh
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    contravariant-1.5.5-1Tz7FaRP9yoKqkcBKkQ76A
    hasql-1.4.5.1-18knPmLQkOq7w3Mwk6lxdc
    hasql-pool-0.5.2-U54rYfY2se7t0wiZUw8nN
    postgresql-libpq-0.9.4.3-4UpE2VczKgl8p7NC0fd3Q8 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
